![](https://raw.githubusercontent.com/xiaoxiae/Florodoro/master/florodoro/images/logo.svg)

---

A pomodoro timer that grows procedurally generated trees and flowers while you're studying.

![](https://raw.githubusercontent.com/xiaoxiae/Florodoro/master/florodoro/images/preview.svg)

## Running Florodoro
First, install the app by running `pip install florodoro`.
Then you can simply run the `florodoro` command from a terminal of your choice.
